# happy
Library with tools that make any everyday Python user simply happy.

[Documentation](https://github.com/jankukacka/happy/wiki/Documentation)


## Installation

```
pip install happy_tools=1.0.0
```

To keep the library installation lightweight, additional dependencies for file IO are not installed by default.

## License

The software is provided under the [MIT open license](LICENSE.txt).

## Citation
If you use this software for your research, please cite it as:
```
Kukačka, Jan (2021). Happy (v1.0.0) [Computer software]. https://github.com/jankukacka/happy
```
